==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebRowSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectionEventArgsDetailDescriptionMetadata } from "./WebRowSelectionEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDescription } from "./WebRowSelectionEventArgsDescription";
/**
 * @hidden
 */
var WebRowSelectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRowSelectionEventArgsDescriptionMetadata, _super);
    function WebRowSelectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowSelectionEventArgsDescriptionMetadata.a == null) {
            WebRowSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectionEventArgsDescriptionMetadata.c(WebRowSelectionEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebRowSelectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRowSelectionEventArgsDescriptionMetadata.a);
        WebRowSelectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowSelectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowSelectionEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebRowSelectionEventArgsDetail");
    };
    WebRowSelectionEventArgsDescriptionMetadata.d = function (a) {
        WebRowSelectionEventArgsDescriptionMetadata.b(a);
        a.aa("WebRowSelectionEventArgs", function () { return new WebRowSelectionEventArgsDescription(); });
        a.z("WebRowSelectionEventArgs", WebRowSelectionEventArgsDescriptionMetadata.a);
    };
    WebRowSelectionEventArgsDescriptionMetadata.$t = markType(WebRowSelectionEventArgsDescriptionMetadata, 'WebRowSelectionEventArgsDescriptionMetadata');
    WebRowSelectionEventArgsDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDescriptionMetadata;
}(Base));
export { WebRowSelectionEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRowSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectionEventArgsDetailDescriptionMetadata } from "./WebRowSelectionEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDescription } from "./WebRowSelectionEventArgsDescription";
/**
 * @hidden
 */
var WebRowSelectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRowSelectionEventArgsDescriptionMetadata, _super);
    function WebRowSelectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowSelectionEventArgsDescriptionMetadata.a == null) {
            WebRowSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectionEventArgsDescriptionMetadata.c(WebRowSelectionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebRowSelectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowSelectionEventArgsDescriptionMetadata.a);
        WebRowSelectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowSelectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowSelectionEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebRowSelectionEventArgsDetail");
    };
    WebRowSelectionEventArgsDescriptionMetadata.d = function (a) {
        WebRowSelectionEventArgsDescriptionMetadata.b(a);
        a.ac("WebRowSelectionEventArgs", function () { return new WebRowSelectionEventArgsDescription(); });
        a.ab("WebRowSelectionEventArgs", WebRowSelectionEventArgsDescriptionMetadata.a);
    };
    WebRowSelectionEventArgsDescriptionMetadata.$t = markType(WebRowSelectionEventArgsDescriptionMetadata, 'WebRowSelectionEventArgsDescriptionMetadata');
    WebRowSelectionEventArgsDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDescriptionMetadata;
}(Base));
export { WebRowSelectionEventArgsDescriptionMetadata };
